==> klass-0.0.1.tgz: package/src/klass.js <==
!function (context) {

  function methods(o) {
    for (var k in o) {
      o.hasOwnProperty(k) && wrapper.call(this, o, k);
    }
    return this;
  }

  function statics(o) {
    for (var k in o) {
      o.hasOwnProperty(k) && (this[k] = o[k]);
    }
    return this;
  }

  function wrapper (o, k) {
    var sup = this.prototype.constructor.sup;
    this.prototype[k] = function () {
      this._name = k;
      this.sup = sup;
      return o[k].apply(this, arguments);
    };
  }

  function klass(fn) {
    fn.methods = methods;
    fn.statics = statics;
    return fn;
  }

  function extend(sup, sub) {

    function fn() {
      sup.apply(this, arguments);
      sub.apply(this, arguments);
    }

    var F = function(){};
    F.prototype = sup.prototype;
    fn.prototype = new F();
    fn.methods = methods;
    fn.statics = statics;
    fn.prototype.constructor = sub;
    fn.prototype.constructor.sup = sup;
    fn.prototype.supr = function () {
      if (this.sup.prototype[this._name]) {
        return this.sup.prototype[this._name].apply(this, arguments);
      }
    };
    return fn;
  }

  function implement(inst, o) {
    inst.sup = inst.constructor.prototype.constructor.sup;
    function f(n) {
      return function() {
        n.apply(inst, arguments);
      };
    }
    for (var k in o) {
      o.hasOwnProperty(k) && (inst[k] = f(o[k]));
    }
  }

  if (typeof module !== 'undefined' && module.exports) {
    module.exports = {
      klass: klass,
      extend: extend,
      implement: implement
    };
  } else {
    context.klass = klass;
    context.extend = extend;
    context.implement = implement;
  }

}(this);

==> klass-0.0.3.tgz: package/src/klass.js <==
!function (context) {

  function noop() {}

  function methods(o) {
    for (var k in o) {
      o.hasOwnProperty(k) && wrapper.call(this, o, k);
    }
    return this;
  }

  function statics(o) {
    for (var k in o) {
      o.hasOwnProperty(k) && (this[k] = o[k]);
    }
    return this;
  }

  function wrapper (o, k) {
    var sup = this.prototype.constructor.sup;
    this.prototype[k] = function () {
      this._name = k;
      this.sup = sup;
      return o[k].apply(this, arguments);
    };
  }

  function klass(fn) {
    var o = typeof fn != 'function' && fn;
    fn = (typeof fn == 'function') ? fn : noop;

    fn.methods = methods;
    fn.statics = statics;
    fn.extend = extend;
    fn.prototype.implement = implement;
    return o ? fn.methods(o) : fn;
  }

  function extend(sub) {
    var sup = this;

    function fn() {
      sup.apply(this, arguments);
      typeof sub == 'function' && sub.apply(this, arguments);
    }

    var F = function (){};
    F.prototype = sup.prototype;
    fn.prototype = new F();
    klass(fn);


    fn.prototype.constructor = fn;
    fn.prototype.constructor.sup = sup;
    fn.prototype.supr = function () {
      if (this.sup.prototype[this._name]) {
        return this.sup.prototype[this._name].apply(this, arguments);
      }
    };

    return (typeof sub != 'function' && sub && fn.methods(sub)) || fn;
  }

  function implement(o) {
    this.constructor.methods(o);
    return this;
  }


  if (typeof module !== 'undefined' && module.exports) {
    module.exports = klass;
  } else {
    context.klass = klass;
  }

}(this);
